@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.204 2005/08/08 17:57:37 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.205 2005/09/02 11:22:01 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -1136,8 +1136,7 @@ bacon_video_widget_realize (GtkWidget *widget)
 
 	bvw->priv->ao_driver = load_audio_out_driver (bvw, FALSE, NULL);
 
-	if (bvw->priv->type == BVW_USE_TYPE_VIDEO
-			&& bvw->priv->ao_driver != NULL
+	if (bvw->priv->ao_driver != NULL
 			&& bvw->priv->ao_driver_none == FALSE)
 	{
 		if (bvw->priv->vis_name == NULL)
@@ -1882,6 +1881,9 @@ show_vfx_update (BaconVideoWidget *bvw, gboolean show_visuals)
 	/* Doesn't have video, but visual effects are disabled */
 	} else if (has_video == FALSE && show_visuals == FALSE) {
 		enable = FALSE;
+	/* No changes */
+	} else {
+		return;
 	}
 
 	if (enable == FALSE) {
@@ -2812,6 +2814,10 @@ bacon_video_widget_set_visuals (BaconVideoWidget *bvw, const char *name)
 		g_free (bvw->priv->vis_name);
 		bvw->priv->vis_name = g_strdup (name);
 		show_vfx_update (bvw, TRUE);
+	} else {
+		g_free (bvw->priv->vis_name);
+		bvw->priv->vis_name = g_strdup (name);
+		show_vfx_update (bvw, FALSE);
 	}
 
 	return FALSE;
