@@ -12,9 +12,11 @@
 
 typedef struct TotemTimeLabel	      TotemTimeLabel;
 typedef struct TotemTimeLabelClass    TotemTimeLabelClass;
+typedef struct TotemTimeLabelPrivate  TotemTimeLabelPrivate;
 
 struct TotemTimeLabel {
 	GtkLabel parent;
+	TotemTimeLabelPrivate *priv;
 };
 
 struct TotemTimeLabelClass {
@@ -25,5 +27,9 @@ GtkType    totem_time_label_get_type 	(void);
 GtkWidget *totem_time_label_new      	(void);
 void       totem_time_label_set_time    (TotemTimeLabel *label,
 					 gint64 time, gint64 length);
+GtkWidget *totem_time_label_new_from_glade
+					(gchar *widget_name,
+					 gchar *string1, gchar *string2,
+					 gint int1, gint int2);
 
 #endif /* TOTEM_TIME_LABEL_H */
